@@ -1,13 +1,15 @@
 #ifndef CANDIDATELISTBOX_H
 #define CANDIDATELISTBOX_H
 
-#include <qframe.h>
-#include <qstringlist.h>
-#include <qpoint.h>
+#include <QFrame>
+#include <QStringList>
+#include <QPoint>
 
-class QListBox;
-class QListBoxItem;
+class QListWidget;
+class QListWidgetItem;
 class QLabel;
+class QShowEvent;
+class QHideEvent;
 
 class CandidateListBox : public QFrame {
   Q_OBJECT
@@ -16,8 +18,9 @@ public:
   enum {
     MAX_VISIBLE_ITEMS = 9,
   };
+  
+  CandidateListBox(QWidget* parent = 0);
 
-  CandidateListBox();
   void showList(const QStringList& strs, int crntidx = 0);
   void selectCandidate(int idx);
   void selectPreviousCandidate(uint decrement = 1);
@@ -37,7 +40,7 @@ public slots:
   void showCandidatePredicted(const QString& str);
 
 signals:
-  void clicked(QListBoxItem* item);
+  void clicked(QListWidgetItem* item);
 
 protected:
   void showEvent(QShowEvent *);
@@ -45,12 +48,11 @@ protected:
 
 protected slots:
   void setLabelValue(int d);
-  void adjustDisplay();
 
 private:
-  QListBox*    _lbl;
-  QListBox*    _lstbox;
-  QLabel*      _crntitem;
+  QListWidget* _lbl;
+  QListWidget* _lstbox;
+  QLabel*      _crntitemno;
   QLabel*      _predictxt;
   QPoint       _pos;
 };
