@@ -2,16 +2,15 @@
 #include "kimeraglobal.h"
 #include "config.h"
 #include "debug.h"
-#include <qapplication.h>
-#include <qeventloop.h>
-#include <qmessagebox.h>
-#include <qcstring.h>
-#include <qdatastream.h>
-#include <qtextcodec.h>
-#include <qsocket.h>
-#include <qdatetime.h>
-#include <qstringlist.h>
-#include <sys/types.h>
+#include <QApplication>
+#include <QEventLoop>
+#include <QMessageBox>
+#include <QDataStream>
+#include <QTextCodec>
+#include <QDateTime>
+#include <QStringList>
+#include <QTimerEvent>
+#include <QtNetwork/QTcpSocket>
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <unistd.h>
@@ -22,19 +21,16 @@
 static QStringList CANNA_AF_UNIX_FILES;
 
 CannaEngine::CannaEngine() 
-  : _contxt(0), _convertflag(FALSE), _connectimer(0)
+  : _sock(new QTcpSocket(this)), _contxt(0), _convertflag(false), _connectimer(0)
 {
   CANNA_AF_UNIX_FILES << "/tmp/.iroha_unix/IROHA" << "/var/run/.iroha_unix/IROHA";
-  _sock = new QSocket();
   connect(_sock, SIGNAL(connected()), this, SLOT(slotConnected()));
-  connect(_sock, SIGNAL(error(int)), this, SLOT(slotDetectError()));
-  connect(_sock, SIGNAL(connectionClosed()), this, SLOT(slotConnectionClosed()));
+  connect(_sock, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(slotDetectError(QAbstractSocket::SocketError)));
 }
 
 
 CannaEngine::~CannaEngine()
 {
-  delete _sock;
 }
 
 
@@ -48,7 +44,7 @@ CannaEngine::name() const
 bool
 CannaEngine::isTCPConnectionSupported() const
 {
-  return TRUE;
+  return true;
 }
 
 
@@ -59,7 +55,7 @@ CannaEngine::init()
   DEBUG_TRACEFUNC();
   _sock->close();
   
-  if ( Config::readBoolEntry("_grpremote", FALSE) ) {
+  if ( Config::readBoolEntry("_grpremote", false) ) {
     // INET Domain
     qDebug("INET Domain socket");
     _sock->connectToHost(Config::readEntry("_edtsvrname", "localhost"), 
@@ -75,7 +71,7 @@ CannaEngine::init()
       QMessageBox::critical(0, "Kanji Server Error", 
 			    "Socket Create Error",
 			    QMessageBox::Ok | QMessageBox::Default, 0);
-      return FALSE;
+      return false;
     }
 
     int i;
@@ -83,7 +79,7 @@ CannaEngine::init()
       struct sockaddr_un  addr;
       memset(&addr, 0, sizeof(addr));
       addr.sun_family = AF_UNIX;
-      strncpy(addr.sun_path, CANNA_AF_UNIX_FILES[i].latin1(), sizeof(addr.sun_path) - 1);
+      strncpy(addr.sun_path, CANNA_AF_UNIX_FILES[i].toAscii(), sizeof(addr.sun_path) - 1);
       
       // connect
       if ( !::connect(fd, (sockaddr *)&addr, sizeof(addr)) )
@@ -95,24 +91,28 @@ CannaEngine::init()
 			    "Socket Connection Error",
 			    QMessageBox::Ok | QMessageBox::Default, 0);
       ::close(fd);
-      return FALSE;
+      return false;
     }
     
-    _sock->setSocket(fd);  // UNIX Domain socket set
+    _sock->setSocketDescriptor(fd);  // UNIX Domain socket set
     slotConnected();
   }
 
-  return TRUE;
+  return true;
 }
 
 
-void 
+void
 CannaEngine::cleanup()
 {
   DEBUG_TRACEFUNC();
-  _sock->close();
+  qDebug("SocketState before cleanup: %d", _sock->state());
+
+  if (_sock->state() != QAbstractSocket::UnconnectedState && _sock->state() != QAbstractSocket::ClosingState) {
+    _sock->close();
+  }
   _contxt = 0;
-  _convertflag = FALSE;
+  _convertflag = false;
   if (_connectimer > 0) {
     killTimer(_connectimer);
     _connectimer = 0;
@@ -124,36 +124,22 @@ void
 CannaEngine::slotConnected() 
 {
   DEBUG_TRACEFUNC();
-  qDebug("socket: %d", _sock->socket());
+  qDebug("socket: %d", _sock->socketDescriptor());
   sendInitialize();
 }
 
 
 void 
-CannaEngine::slotDetectError() 
+CannaEngine::slotDetectError(QAbstractSocket::SocketError error) 
 {
-  DEBUG_TRACEFUNC();
-  cleanup();
-  Config::writeEntry("_grpremote", FALSE);
-  
+  DEBUG_TRACEFUNC("SocketError: %d", (int)error);
+
   QMessageBox::critical(0, "Kanji Server Error", 
 			tr("Canna Ȥ̿ǥ顼ȯޤ\n"
 			   "ʴѴߤޤ"),
 			QMessageBox::Ok | QMessageBox::Default, 0);
-}
-
-
-void
-CannaEngine::slotConnectionClosed()
-{
-  DEBUG_TRACEFUNC();
   cleanup();
-  Config::writeEntry("_grpremote", FALSE);
-
-  QMessageBox::warning(0, "Kanji Server Connection Closed",
-		       tr("Canna ȤΥåǤޤ\n"
-			  "ʴѴߤޤ"),
-		       QMessageBox::Ok | QMessageBox::Default, 0);
+  Config::writeEntry("_grpremote", false);
 }
 
 
@@ -162,21 +148,21 @@ CannaEngine::sendInitialize()
 {
   DEBUG_TRACEFUNC();
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  QCString user("3.3:");
+  QByteArray user("3.3:");
   struct passwd* pass = getpwuid( getuid() );
-  user += QCString(pass->pw_name);
+  user += QString(pass->pw_name);
   ds << (int)RID_INITIALIZE << (int)user.length() + 1;
-  ds.writeRawBytes(user.data(), user.length() + 1);
-  _sock->writeBlock(pack.data(), pack.size());
+  ds.writeRawData(user.data(), user.length() + 1);
+  _sock->write(pack.data(), pack.size());
   
   // wait for replay
   QTime t;
   t.start();
   while (_sock->bytesAvailable() != 4) {
-    qApp->eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+    QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
     if (t.elapsed() > 2000) {
       qWarning("No response!");
       return;
@@ -196,12 +182,12 @@ CannaEngine::recvInitializeReply()
     qWarning("Server response incorrect.  %s:%d", __FILE__, __LINE__);
   } 
   
-  QByteArray respack(len);
-  QDataStream ds(respack, IO_ReadOnly);
+  QByteArray respack(len, 0);
+  QDataStream ds(respack);
   ds.setByteOrder(QDataStream::BigEndian);
 
   // response packet recv
-  if (_sock->readBlock(respack.data(), len) < 0) {
+  if (_sock->read(respack.data(), len) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return;
   }
@@ -216,9 +202,9 @@ CannaEngine::recvInitializeReply()
     return;
   } 
 
-  QDataStream dst(respack, IO_ReadOnly);
+  QDataStream dst(respack);
   dst.setByteOrder(QDataStream::BigEndian);
-  u_int16_t  minor;
+  quint16  minor;
   dst >> minor >> _contxt;
   qDebug("minor version: %d  context: %d", minor, _contxt);
 
@@ -231,10 +217,10 @@ CannaEngine::noticeGroupName()
 {
   DEBUG_TRACEFUNC();
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  char* gname = "users";
+  const char* gname = "users";
   struct passwd* pass = getpwuid( getuid() );
   if ( pass ) {
     struct group* grp = getgrgid(pass->pw_gid);
@@ -243,11 +229,11 @@ CannaEngine::noticeGroupName()
     }
   }
 
-  u_int16_t glen = strlen(gname) + 1;
-  ds << (u_int8_t)RID_NOTICE_GROUP_NAME << (u_int8_t)0 << (u_int16_t)(glen + 6)
+  quint16 glen = strlen(gname) + 1;
+  ds << (quint8)RID_NOTICE_GROUP_NAME << (quint8)0 << (quint16)(glen + 6)
      << (int)0 << _contxt;
-  ds.writeRawBytes(gname, glen);
-  _sock->writeBlock(pack.data(), pack.size());
+  ds.writeRawData(gname, glen);
+  _sock->write(pack.data(), pack.size());
 
   if ( !waitForReply(RID_NOTICE_GROUP_NAME) ) {
     slotDetectError();
@@ -263,23 +249,23 @@ CannaEngine::recvNoticeGroupName()
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return;
   }
 
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  u_int16_t len;
+  quint16 len;
   ds >> len;
   
   if (len != datalen - 2) {
     qWarning("Server response incorrect.  %s", __func__);
   } 
   
-  int8_t  stat;
+  qint8  stat;
   ds >> stat;
   if (stat) {
     cleanup();
@@ -299,11 +285,11 @@ CannaEngine::getDictionaryList()
 {
   DEBUG_TRACEFUNC();
   QByteArray  pack;
-  QDataStream ds(pack, IO_ReadWrite);
+  QDataStream ds(&pack, QIODevice::ReadWrite);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  ds << (u_int8_t)RID_GET_DICTIONARY_LIST << (u_int8_t)0 << (u_int16_t)4 << _contxt << (u_int16_t)4096;
-  _sock->writeBlock(pack.data(), pack.size());
+  ds << (quint8)RID_GET_DICTIONARY_LIST << (quint8)0 << (quint16)4 << _contxt << (quint16)4096;
+  _sock->write(pack.data(), pack.size());
 
   if ( !waitForReply(RID_GET_DICTIONARY_LIST) ) {
     slotDetectError();
@@ -319,16 +305,16 @@ CannaEngine::recvGetDictionaryListReply()
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return;
   }
 
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  int16_t len, ndic;
+  qint16 len, ndic;
   ds >> len >> ndic;
   
   if (len != (int)datalen - 2) {
@@ -340,7 +326,7 @@ CannaEngine::recvGetDictionaryListReply()
   QStringList diclist;
   for (int i = 0; i < ndic; i++) {
     dic = QString();
-    int8_t s;
+    qint8 s;
     while (1) {
       ds >> s;
       if ( !s ) break;
@@ -367,17 +353,17 @@ CannaEngine::mountDictionary(QString dic)
   DEBUG_TRACEFUNC();
 
   QByteArray  pack;
-  QDataStream ds(pack, IO_ReadWrite);
+  QDataStream ds(&pack, QIODevice::ReadWrite);
   ds.setByteOrder(QDataStream::BigEndian);
     
-  qDebug("request mount dictionary name: %s", dic.data());    
-  ds << (u_int8_t)RID_MOUNT_DICTIONARY << (u_int8_t)0 << (u_int16_t)(dic.length()+7) << (int)0x0200 << _contxt;
-  ds.writeRawBytes(dic.latin1(), dic.length() + 1);
-  _sock->writeBlock(pack.data(), pack.size());
+  qDebug("request mount dictionary name: %s", qPrintable(dic));    
+  ds << (quint8)RID_MOUNT_DICTIONARY << (quint8)0 << (quint16)(dic.length()+7) << (int)0x0200 << _contxt;
+  ds.writeRawData(dic.toAscii(), dic.length() + 1);
+  _sock->write(pack.data(), pack.size());
 
   if ( !waitForReply(RID_MOUNT_DICTIONARY) ) {
     slotDetectError();
-    return FALSE;
+    return false;
   }
 
   return recvMountDictionaryReply();
@@ -389,68 +375,67 @@ CannaEngine::recvMountDictionaryReply()
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
-    return FALSE;
+    return false;
   }
 
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  int16_t len;
+  qint16 len;
   ds >> len;
   
   if (len != (int)datalen - 2) {
     qWarning("Server response incorrect.  %s", __func__);
-    return FALSE;
+    return false;
   } 
   
-  int8_t  stat;
+  qint8  stat;
   ds >> stat;
   if (stat) {
     cleanup();
     QMessageBox::critical(0, "mount dictionary error",
 			  "Canna mount dictionary error",
 			  QMessageBox::Ok | QMessageBox::Default, 0);
-    return FALSE;
+    return false;
   }  
   qDebug("mount dictionary successful.");
-  return TRUE;
+  return true;
 }
 
 
 bool
 CannaEngine::beginConvert(const QString& hira, QStringList& kanji, QStringList& yomigana)
 {
-  DEBUG_TRACEFUNC();
-  if ( _sock->state() != QSocket::Connected )
-    return FALSE;
+  DEBUG_TRACEFUNC("hira: %s", qPrintable(hira));
+  if ( _sock->state() != QAbstractSocket::ConnectedState )
+    return false;
 
   if ( _convertflag ) {
     qWarning("%s:_convertflag incorrect", __func__);
-    return FALSE;
+    return false;
   }
 
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  qDebug("Yomigana size(QCString): %d", hira.local8Bit().length());
-  //QByteArray str = eucToUint16(hira.local8Bit());
+  qDebug("Yomigana size(euc): %d", hira.toLocal8Bit().length());
   QByteArray str = eucToUint16(QTextCodec::codecForTr()->fromUnicode(hira));
   qDebug("Yomigana size(uint16 array): %d", str.size());
 
-  ds << (u_int8_t)RID_BEGIN_CONVERT << (u_int8_t)0 << (u_int16_t)(str.size()+6) << 0L << _contxt;
-  ds.writeRawBytes(str.data(), str.size());
-  _sock->writeBlock(pack.data(), pack.size());
+  ds << (quint8)RID_BEGIN_CONVERT << (quint8)0 << (quint16)(str.size()+6) << (int)0 << _contxt;
+  ds.writeRawData(str.data(), str.size());
+  _sock->write(pack.data(), pack.size());
 
-  _convertflag = TRUE;  // start converting
+  _convertflag = true;  // start converting
   qDebug("beginConvert in progress ...");
  
   if ( !waitForReply(RID_BEGIN_CONVERT) ) {
     slotDetectError();
-    return FALSE;
+    return false;
   }
 
   kanji = recvBeginConvertReply();
@@ -458,12 +443,12 @@ CannaEngine::beginConvert(const QString& hira, QStringList& kanji, QStringList&
   for (int i = 0; i < (int)kanji.count(); ++i) {
     QString str = getYomi(i);
     if (str.isEmpty())
-      return FALSE;
+      return false;
     yomigana << str;
   }
 
   Q_ASSERT(kanji.count() == yomigana.count());
-  return TRUE;
+  return true;
 }
 
 
@@ -473,23 +458,23 @@ CannaEngine::recvBeginConvertReply()
   DEBUG_TRACEFUNC();
 
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return QStringList();
   }
 
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  int16_t len;
+  qint16 len;
   ds >> len;
   
   if (len != (int)datalen - 2) {
     qWarning("beginConvert: server response incorrect. (%s)", __func__);
   } 
 
-  int16_t nbunsetu;
+  qint16 nbunsetu;
   ds >> nbunsetu;
   if (nbunsetu <= 0) {
     qDebug("beginConvert: convert error.  %s", __func__);
@@ -499,9 +484,9 @@ CannaEngine::recvBeginConvertReply()
   QStringList strlist;
   for (int i = 0; i < nbunsetu; i++) {
     QByteArray  ba;
-    QDataStream dsba(ba, IO_WriteOnly);
+    QDataStream dsba(&ba, QIODevice::WriteOnly);
     dsba.setByteOrder(QDataStream::BigEndian);
-    u_int16_t us;
+    quint16 us;
 
     ds >> us;
     while (us) {
@@ -515,7 +500,7 @@ CannaEngine::recvBeginConvertReply()
   }
 
   qDebug("beginConvert successful");
-  qDebug("[%s]  %s", __func__, strlist.join(" ").local8Bit().data());
+  qDebug("[%s]  %s", __func__, qPrintable(strlist.join(" ")));
   return strlist;
 }
 
@@ -524,7 +509,7 @@ void
 CannaEngine::endConvert(const QStringList &)
 {
   DEBUG_TRACEFUNC();
-  if ( _sock->state() != QSocket::Connected )
+  if ( _sock->state() != QAbstractSocket::ConnectedState )
     return;
 
   if ( !_convertflag ) {
@@ -533,14 +518,14 @@ CannaEngine::endConvert(const QStringList &)
   }
 
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  ds << (u_int8_t)RID_END_CONVERT << (u_int8_t)0 << (u_int16_t)8 << _contxt 
-     << (int16_t)0 << 0L;
-  _sock->writeBlock(pack.data(), pack.size());
+  ds << (quint8)RID_END_CONVERT << (quint8)0 << (quint16)8 << _contxt 
+     << (qint16)0 << (int)0;
+  _sock->write(pack.data(), pack.size());
 
-  _convertflag = FALSE;  // conversion done
+  _convertflag = false;  // conversion done
   qDebug("%s: done", __func__);
 
   if ( !waitForReply(RID_END_CONVERT) ) {
@@ -557,16 +542,16 @@ CannaEngine::recvEndConvertReply() const
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return;
   }
   
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  int16_t len;
+  qint16 len;
   ds >> len;
   
   if (len != (int)datalen - 2) {
@@ -574,7 +559,7 @@ CannaEngine::recvEndConvertReply() const
     return;
   }
   
-  int8_t res;
+  qint8 res;
   ds >> res;
   if ( res ) {
     qFatal("End Convert error.  %s:%d", __FILE__, __LINE__);
@@ -589,27 +574,27 @@ bool
 CannaEngine::getCandidate(int idx, QStringList& candidate)
 {
   DEBUG_TRACEFUNC("idx: %d", idx);
-  if ( _sock->state() != QSocket::Connected )
-    return FALSE;
+  if ( _sock->state() != QAbstractSocket::ConnectedState )
+    return false;
 
   if ( !_convertflag )
-    return FALSE;
+    return false;
  
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  ds << (u_int8_t)RID_GET_CANDIDATE_LIST << (u_int8_t)0 << (u_int16_t)6 << _contxt 
-     << (int16_t)idx << (u_int16_t)4096;
-  _sock->writeBlock(pack.data(), pack.size());
+  ds << (quint8)RID_GET_CANDIDATE_LIST << (quint8)0 << (quint16)6 << _contxt 
+     << (qint16)idx << (quint16)4096;
+  _sock->write(pack.data(), pack.size());
 
   if ( !waitForReply(RID_GET_CANDIDATE_LIST) ) {
     slotDetectError();
-    return FALSE;
+    return false;
   }
 
   candidate = recvGetCandidateListReply();
-  return TRUE;
+  return true;
 }
 
 
@@ -618,16 +603,16 @@ CannaEngine::recvGetCandidateListReply()
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return QStringList();
   }
   
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  int16_t len;
+  qint16 len;
   ds >> len;
   
   if (len != (int)datalen - 2) {
@@ -635,7 +620,7 @@ CannaEngine::recvGetCandidateListReply()
     return QStringList();
   }
 
-  int16_t ncand;
+  qint16 ncand;
   ds >> ncand;
   if (ncand < 0) {
     qFatal("GetCandidateList error.  %s:%d", __FILE__, __LINE__);
@@ -650,9 +635,9 @@ CannaEngine::recvGetCandidateListReply()
   QStringList  listcand;
   for (int i = 0; i < ncand; i++) {
     QByteArray  ba;
-    QDataStream dsba(ba, IO_WriteOnly);
+    QDataStream dsba(&ba, QIODevice::WriteOnly);
     dsba.setByteOrder(QDataStream::BigEndian);
-    u_int16_t us;
+    quint16 us;
     
     ds >> us;
     while (us) {
@@ -661,12 +646,12 @@ CannaEngine::recvGetCandidateListReply()
     }    
     
     QString str = tr(uint16ToEuc(ba));
-    if ( !str.isEmpty() && listcand.find(str) == listcand.end()) {
+    if ( ! listcand.contains(str) ) {
       listcand << str;
     }
   }
   
-  qDebug("[%s]  %s", __func__, listcand.join(" ").local8Bit().data());
+  qDebug("[%s]  %s", __func__, qPrintable(listcand.join(" ")));
   return listcand;
 }
 
@@ -679,12 +664,12 @@ CannaEngine::getYomi(int idx)
     return QString::null;
 
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  ds << (u_int8_t)RID_GET_YOMI << (u_int8_t)0 << (u_int16_t)6 << _contxt 
-     << (int16_t)idx << (u_int16_t)4096;
-  _sock->writeBlock(pack.data(), pack.size());
+  ds << (quint8)RID_GET_YOMI << (quint8)0 << (quint16)6 << _contxt 
+     << (qint16)idx << (quint16)4096;
+  _sock->write(pack.data(), pack.size());
   
   if ( !waitForReply(RID_GET_YOMI) ) {
     slotDetectError();
@@ -700,16 +685,16 @@ CannaEngine::recvGetYomiReply()
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return QString::null;
   }
   
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  int16_t len;
+  qint16 len;
   ds >> len;
   
   if (len != (int)datalen - 2) {
@@ -717,13 +702,13 @@ CannaEngine::recvGetYomiReply()
     return QString::null;
   }
   
-  int16_t n;
+  qint16 n;
   ds >> n;
   
   QByteArray  ba;
-  QDataStream dsba(ba, IO_WriteOnly);
+  QDataStream dsba(&ba, QIODevice::WriteOnly);
   dsba.setByteOrder(QDataStream::BigEndian);
-  u_int16_t us;
+  quint16 us;
   
   ds >> us;
   while (us) {
@@ -739,12 +724,12 @@ bool
 CannaEngine::resizeSegment(int idx, int len, QStringList& kanji, QStringList& yomigana)
 {
   DEBUG_TRACEFUNC("idex: %d  len: %d", idx, len);
-  if ( _sock->state() != QSocket::Connected )
-    return FALSE;
+  if ( _sock->state() != QAbstractSocket::ConnectedState )
+    return false;
 
   if ( !_convertflag ) {
     Q_ASSERT(0);
-    return FALSE;
+    return false;
   }
 
   if (len < 0) {
@@ -753,17 +738,17 @@ CannaEngine::resizeSegment(int idx, int len, QStringList& kanji, QStringList& yo
   }
 
   QByteArray  pack;
-  QDataStream ds(pack, IO_WriteOnly);
+  QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  ds << (u_int8_t)RID_RESIZE_PAUSE << (u_int8_t)0 
-     << (u_int16_t)6 << _contxt 
-     << (int16_t)idx << (u_int16_t)len;
-  _sock->writeBlock(pack.data(), pack.size());
+  ds << (quint8)RID_RESIZE_PAUSE << (quint8)0 
+     << (quint16)6 << _contxt 
+     << (qint16)idx << (quint16)len;
+  _sock->write(pack.data(), pack.size());
 
   if ( !waitForReply(RID_RESIZE_PAUSE) ) {
     slotDetectError();
-    return FALSE;
+    return false;
   }
 
   kanji = recvResizePause();
@@ -771,12 +756,12 @@ CannaEngine::resizeSegment(int idx, int len, QStringList& kanji, QStringList& yo
   for (int i = 0; i < (int)kanji.count(); ++i) {
     QString str = getYomi(idx + i);
     if (str.isEmpty())
-      return FALSE;
+      return false;
     yomigana << str;
   }
 
   Q_ASSERT(kanji.count() == yomigana.count());
-  return TRUE;
+  return true;
 }
 
 
@@ -785,16 +770,16 @@ CannaEngine::recvResizePause()
 {
   DEBUG_TRACEFUNC();
   uint datalen = _sock->size();
-  QByteArray data(datalen);
-  if (_sock->readBlock(data.data(), datalen) < 0) {
+  QByteArray data(datalen, 0);
+  if (_sock->read(data.data(), datalen) < 0) {
     qFatal("Recv error.  %s:%d", __FILE__, __LINE__);
     return QStringList();
   }
   
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(QDataStream::BigEndian);
   
-  int16_t len;
+  qint16 len;
   ds >> len;
   
   if (len != (int)datalen - 2) {
@@ -802,7 +787,7 @@ CannaEngine::recvResizePause()
     return QStringList();
   }
   
-  int16_t nbunsetu;
+  qint16 nbunsetu;
   ds >> nbunsetu;
   if (nbunsetu <= 0) {
     qDebug("Convert error.  %s", __func__);
@@ -814,9 +799,9 @@ CannaEngine::recvResizePause()
   QStringList strlist;
   for (int i = 0; i < nbunsetu; i++) {
     QByteArray  ba;
-    QDataStream dsba(ba, IO_WriteOnly);
+    QDataStream dsba(&ba, QIODevice::WriteOnly);
     dsba.setByteOrder(QDataStream::BigEndian);
-    u_int16_t us;
+    quint16 us;
 
     ds >> us;
     while (us && !ds.atEnd()) {
@@ -829,7 +814,7 @@ CannaEngine::recvResizePause()
       strlist << str;
   }
 
-  qDebug("[%s]  %s", __func__, strlist.join(" ").local8Bit().data());
+  qDebug("[%s]  %s", __func__, qPrintable(strlist.join(" ")));
   return strlist;
 }
 
@@ -840,59 +825,58 @@ CannaEngine::waitForReply(int msgid, int msecs)
   DEBUG_TRACEFUNC("msgid:%d msecs:%d", msgid, msecs);
 
   _sock->flush();
-  bool timeout;
-  Q_LONG size = _sock->waitForMore(msecs, &timeout);
-  if (!size || timeout) {
-    qDebug("Timeout!  size:%ld", size);
-    return FALSE;
+  if ( !_sock->waitForReadyRead( msecs ) ) {
+    qDebug("Timeout or SocketError!  [waitForReadyRead()]");
+    return false;
   }
 
-  char buf[2];
-  size = _sock->readBlock(buf, 2);
+  char buf[2] = "";
+  qint64 size = _sock->read(buf, 2);
   if (size != 2) {
-    qFatal("Recv error %ld  %s:%d", size, __FILE__, __LINE__);
-    return FALSE;
+    qFatal("Recv error %d  %s:%d", (int)size, __FILE__, __LINE__);
+    return false;
   }
   if (buf[0] != msgid) {
-    qWarning("Bad message ID : req:0x%x  recv:0x%x", (u_int8_t)msgid, (u_int8_t)buf[0]);
-    return FALSE;
+    qWarning("Bad message ID : req:0x%x  recv:0x%x", (quint8)msgid, (quint8)buf[0]);
+    return false;
   }
   
-  return TRUE;
+  return true;
 }
 
 
 // ֵͤϥͥåȥХȥѴѤʤΤǡľǽ
-//  (u_int16_t)0 ɲ
+//  (quint16)0 ɲ
 QByteArray 
-CannaEngine::eucToUint16(const QCString& src)
+CannaEngine::eucToUint16(const QByteArray& src)
 {
+  DEBUG_TRACEFUNC("src: %s", src.data());
+
   QByteArray dest;
-  QDataStream dsdest(dest, IO_ReadWrite);
+  QDataStream dsdest(&dest, QIODevice::ReadWrite);
   dsdest.setByteOrder(QDataStream::BigEndian);
 
-  QCString::ConstIterator it = src.begin();
+  QByteArray::ConstIterator it = src.begin();
   while (it != src.end()) {
-
     if (!(*it & 0x80)) {
       // ASCII
-      dsdest << (u_int16_t)*it;
+      dsdest << (quint16)*it;
 
     } else if (it + 1 != src.end()) {
-      switch ((u_int8_t)*it) {
+      switch ((quint8)*it) {
       case 0x8e:   // Ⱦѥ	
-	dsdest << (u_int16_t)(0x0080 | (*(++it) & 0x7f));
+	dsdest << (quint16)(0x0080 | (*(++it) & 0x7f));
 	break;
 
       case 0x8f:   // 
 	if (it + 2 == src.end())
 	  return 0;
 	
-	dsdest << (u_int16_t)(0x8000 | ((*(++it) & 0x7f) << 8) | (*(++it) & 0x7f));
+	dsdest << (quint16)(0x8000 | ((*(++it) & 0x7f) << 8) | (*(++it) & 0x7f));
 	break;
 
       default:  // Ѥ
-	dsdest << (u_int16_t)(0x8080 | ((*it & 0x7f) << 8) | (*(++it) & 0x7f));
+	dsdest << (quint16)(0x8080 | ((*it & 0x7f) << 8) | (*(++it) & 0x7f));
 	break;
       }
 
@@ -904,29 +888,29 @@ CannaEngine::eucToUint16(const QCString& src)
     ++it;
   }
   
+  dsdest << (quint16)0;
   return dest;
 }
 
 
 // ϥͥåȥХȥ
-QCString 
+QByteArray
 CannaEngine::uint16ToEuc(const QByteArray& src)
 {
-  QDataStream dssrc(src, IO_ReadOnly);
+  QDataStream dssrc(src);
   dssrc.setByteOrder(QDataStream::BigEndian);
-  QCString dst;
-  QDataStream  dsdst(dst, IO_WriteOnly);
+  QByteArray dst;
+  QDataStream  dsdst(&dst, QIODevice::WriteOnly);
   dsdst.setByteOrder(QDataStream::BigEndian);
 
-  u_int8_t b;
-  QCString str;
+  quint8 b;
   while (!dssrc.atEnd()) {
-    u_int16_t us;
+    quint16 us;
     dssrc >> us;
  
     switch (us & 0x8080) {
     case 0:  // ASCII
-      dsdst << (u_int8_t)(us & 0x007f);
+      dsdst << (quint8)(us & 0x007f);
       break;
 
     case 0x0080:  // Ⱦѥ
@@ -934,16 +918,17 @@ CannaEngine::uint16ToEuc(const QByteArray& src)
       break;
 
     case 0x8000:  // 
-      dsdst << (u_int8_t)0x8f;
+      dsdst << (quint8)0x8f;
       dsdst << us;
       break;
 
     case 0x8080:  // Ѥ
       b = (us & 0xff00) >> 8;
-      if (b >= 0xa1 && b <= 0xa8 || b >= 0xb0 && b <= 0xf4) {  // EUC code
+      if ((b >= 0xa1 && b <= 0xa8) || (b >= 0xb0 && b <= 0xf4)) {  // EUC code
 	dsdst << us;
 	
       } else if (us >= 0xada1 && us <= 0xadb4) {
+        QString str;
 	str.sprintf("(%u)", us - 0xada0);
 	dst += str;
 
@@ -958,7 +943,7 @@ CannaEngine::uint16ToEuc(const QByteArray& src)
     }
   }
   
-  dsdst << (u_int8_t)0;
+  dsdst << (quint8)0;
   return dst;
 }
 
@@ -971,10 +956,10 @@ CannaEngine::timerEvent(QTimerEvent* e)
     killTimer(_connectimer);
     _connectimer = 0;
     
-    if (_sock->state() != QSocket::Connected) {
+    if (_sock->state() != QAbstractSocket::ConnectedState) {
       // Detects error
       cleanup();
-      Config::writeEntry("_grpremote", FALSE);
+      Config::writeEntry("_grpremote", false);
       
       QMessageBox::warning(0, "Kanji Server Connection Error",
 			   tr("Canna ȤΥåΩǤޤ\n"
