@@ -2,9 +2,10 @@
 #define CANNAENGINE_H
 
 #include "kanjiengine.h"
-#include <stddef.h>
+#include <QString>
+#include <QAbstractSocket>
 
-class QSocket;
+class QTcpSocket;
 
 class CannaEngine : public KanjiEngine {
   Q_OBJECT
@@ -33,7 +34,7 @@ public:
   bool     init();
   void     cleanup();
   bool     beginConvert(const QString& hira, QStringList& kanji, QStringList& yomigana);
-  void     endConvert(const QStringList& kanji=QString::null);
+  void     endConvert(const QStringList& kanji=QStringList());
   bool     getCandidate(int idx, QStringList& candidate);
   bool     resizeSegment(int idx, int len, QStringList& kanji, QStringList& yomigana);
   bool     isConverting() { return _convertflag; }
@@ -54,21 +55,20 @@ protected:
   QString recvGetYomiReply();
   QStringList recvResizePause();
   QString  getYomi(int idx);
-  QByteArray  eucToUint16(const QCString&);
-  QCString    uint16ToEuc(const QByteArray&);
+  QByteArray  eucToUint16(const QByteArray&);
+  QByteArray  uint16ToEuc(const QByteArray&);
   bool   waitForReply(int msgid, int msecs=5000);
 
 protected slots:
   void slotConnected();
-  void slotDetectError();
-  void slotConnectionClosed();
+  void slotDetectError(QAbstractSocket::SocketError error = QAbstractSocket::UnknownSocketError);
 
- protected:
+protected:
   void timerEvent(QTimerEvent *);
 
 private:
-  QSocket*     _sock;
-  int16_t      _contxt;
+  QTcpSocket*  _sock;
+  qint16       _contxt;
   bool         _convertflag;  // TRUE:  conversion in progress
                               // FALSE: conversion done
   int          _connectimer;
