@@ -10,8 +10,8 @@ TraceFunc::prefix()
 { 
   static char str[20];
   memset(str, '#', sizeof(str));
-  str[QMIN(_callcount, sizeof(str) - 1)] = 0;
-  return str; 
+  str[qMin(_callcount, sizeof(str) - 1)] = 0;
+  return str;
 }
 
 #endif
