@@ -6,7 +6,7 @@
 class InputMode {
 public:
   InputMode(int mode = Kimera::Mode_Hiragana | Kimera::Mode_RomaInput) : _mode(mode) { }
-  Kimera::ModeID id() const { return (Kimera::ModeID)_mode; }
+  int id() const { return _mode; }
 
   InputMode& merge(const InputMode& mode)
   {
@@ -19,6 +19,9 @@ public:
     return *this;
   }
 
+  friend bool operator==(const InputMode& m1, const InputMode& m2) { return m1.id() == m2.id(); }
+  friend bool operator!=(const InputMode& m1, const InputMode& m2) { return m1.id() != m2.id(); }
+
 private:
   int  _mode;
 
