@@ -1,9 +1,10 @@
 #ifndef KANJIENGINE_H
 #define KANJIENGINE_H
 
-#include <qobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <QObject>
+#include <QString>
+#include <QStringList>
+#include <QList>
 
 #define EXPORT_KANJIENGINE(ENGINE)                              \
   class Static##ENGINE##Instance {                              \
@@ -35,7 +36,7 @@ public:
   // Kanji conversion
   virtual bool  isKanjiConvEnabled() const;
   virtual bool  beginConvert(const QString& hira, QStringList& kanji, QStringList& yomigana) = 0;
-  virtual void  endConvert(const QStringList& kanji=QString::null) = 0;
+  virtual void  endConvert(const QStringList& kanji=QStringList()) = 0;
   virtual bool  getCandidate(int index, QStringList& candidate) = 0;
   virtual bool  resizeSegment(int index, int length, QStringList& kanji, QStringList& yomigana) = 0;
   virtual bool  isConverting();
@@ -56,7 +57,7 @@ protected:
   KanjiEngine();
   virtual ~KanjiEngine() {}
   
-  friend class QPtrList<KanjiEngine>;
+  friend class QList<KanjiEngine*>;
   friend class KanjiEngineCleanup;
 };
 
