@@ -1,15 +1,15 @@
 #ifndef KIMERAGLOBAL_H
 #define KIMERAGLOBAL_H
 
-#include <qstring.h>
-#include <qdatastream.h>
-#include <qpair.h>
-#include <sys/types.h>
+#include <QDataStream>
+#include <QString>
+#include <QPair>
+#include <QSysInfo>
 
 namespace Kimera {
-  typedef  QPair<u_int16_t, u_int16_t>  ImIcPair;
+  typedef  QPair<quint16, quint16>  ImIcPair;
   
-  const QString KIMERACONF     = QString("/kimera/") + KIMERA_VERSION "/";
+  const QString KIMERACONF =  "/kimera/" KIMERA_VERSION "/";
   
   enum ModeID {
     Mode_Hiragana    = 0x0001,  // Ҥ餬
@@ -93,6 +93,9 @@ namespace Kimera {
   };
 };
 
-extern QDataStream::ByteOrder sysByteOrder();
+inline QDataStream::ByteOrder sysByteOrder()
+{
+  return (QSysInfo::ByteOrder == QSysInfo::BigEndian) ? QDataStream::BigEndian : QDataStream::LittleEndian;
+}
 
 #endif  // KIMERAGLOBAL_H
