@@ -1,5 +1,5 @@
-#include "xicattribute.h"
 #include "kimeraglobal.h"
+#include "xicattribute.h"
 #include "debug.h"
 
 XICAttribute::XICAttribute()
@@ -40,23 +40,23 @@ XICAttribute::~XICAttribute()
 
 
 QByteArray
-XICAttribute::getValue(u_int16_t id) const
+XICAttribute::getValue(quint16 id) const
 {
   QByteArray ret(0);
-  QDataStream ds(ret, IO_WriteOnly);
+  QDataStream ds(&ret, QIODevice::WriteOnly);
   ds.setByteOrder(sysByteOrder());
   
   switch (id) {
   case 0:
-    ds << _inputstyle;
+    ds << (uint)_inputstyle;
     break;
 
   case 1:
-    ds << _clientwin;
+    ds << (uint)_clientwin;
     break;
 
   case 4:
-    ds << _filterevents;
+    ds << (uint)_filterevents;
     break;
 
   default:
@@ -70,56 +70,55 @@ XICAttribute::getValue(u_int16_t id) const
 
 
 void
-XICAttribute::setValue(u_int16_t id, const QByteArray& data)
+XICAttribute::setValue(quint16 id, const QByteArray& data)
 {
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(sysByteOrder());
-  char unused[4];
 
   switch (id) {
   case 0:
     Q_ASSERT(data.size() == sizeof(XIMStyle));
-    ds >> _inputstyle;
+    ds >> (uint&)_inputstyle;
     qDebug("client request input styles:%lx", _inputstyle);
     Q_ASSERT(_inputstyle == OVER_THE_SPOT_STYLE || _inputstyle == ON_THE_SPOT_STYLE
-	     || _inputstyle == ROOT_WINDOW_STYLE);
+    	     || _inputstyle == ROOT_WINDOW_STYLE);
     break;
 
   case 1:
     Q_ASSERT(data.size() == sizeof(Window));
-    ds >> _clientwin;
+    ds >> (uint&)_clientwin;
     break;
 
   case 2:
     while ( !ds.atEnd() ) {
-      u_int16_t id, len;
+      quint16 id, len;
       ds >> id >> len;
-      QByteArray attr(len);
-      ds.readRawBytes(attr.data(), len);
-      ds.readRawBytes((char*)unused, pad(len));    // unused
+      QByteArray attr(len, 0);
+      ds.readRawData(attr.data(), len);
+      ds.skipRawData( pad(len) );    // unused
       setValuePreeditAttr(id, attr);
     }
     break;
     
   case 3:
     while ( !ds.atEnd() ) {
-      u_int16_t id, len;
+      quint16 id, len;
       ds >> id >> len;
-      QByteArray attr(len);  
-      ds.readRawBytes(attr.data(), len);
-      ds.readRawBytes((char*)unused, pad(len));    // unused
+      QByteArray attr(len, 0);  
+      ds.readRawData(attr.data(), len);
+      ds.skipRawData( pad(len) );    // unused
       setValueStatusAttr(id, attr);
     }
     break;
       
   case 4:
-    Q_ASSERT(data.size() == sizeof(ulong));
+    Q_ASSERT(data.size() == sizeof(uint));
     ds >> _filterevents;
     break;
 
   case 5:
     Q_ASSERT(data.size() == sizeof(Window));
-    ds >> _focuswin;
+    ds >> (uint&)_focuswin;
     break;;
 
   default:
@@ -131,21 +130,21 @@ XICAttribute::setValue(u_int16_t id, const QByteArray& data)
 
 
 void
-XICAttribute::setValuePreeditAttr(u_int16_t id, const QByteArray& data)
+XICAttribute::setValuePreeditAttr(quint16 id, const QByteArray& data)
 {
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(sysByteOrder()); 
   QByteArray fs;
-  u_int16_t len;
+  quint16 len;
 
   qDebug("%s id:%d data size:%d", __func__, id, data.size());
   switch (id) {
   case 6:
     ds >> len;
     fs.resize(len);
-    ds.readRawBytes(fs.data(), len);
+    ds.readRawData(fs.data(), len);
     _fontset_predt = fs;
-    qDebug("Preedit Attributes FontSet:%d :%s", _fontset_predt.length(), _fontset_predt.data());
+    qDebug("Preedit Attributes FontSet:%d :%s", _fontset_predt.length(), qPrintable(_fontset_predt));
     break;
     
   case 7:
@@ -167,28 +166,28 @@ XICAttribute::setValuePreeditAttr(u_int16_t id, const QByteArray& data)
     break;
   
   case 10:
-    Q_ASSERT(data.size() == sizeof(ulong));
+    Q_ASSERT(data.size() == sizeof(uint));
     ds >> _fg_predt;
     break;
   
   case 11:
-    Q_ASSERT(data.size() == sizeof(ulong));
+    Q_ASSERT(data.size() == sizeof(uint));
     ds >> _bg_predt;
     break;
   
   case 12:
     Q_ASSERT(data.size() == sizeof(Pixmap));
-    ds >> _bgpix_predt;
+    ds >> (uint&)_bgpix_predt;
     break;
   
   case 13:
     Q_ASSERT(data.size() == sizeof(Colormap));
-    ds >> _color_predt;
+    ds >> (uint&)_color_predt;
     break;
   
   case 14:
     Q_ASSERT(data.size() == sizeof(Atom));
-    ds >> _stdclr_predt;
+    ds >> (uint&)_stdclr_predt;
     break;
   
   case 15:
@@ -198,7 +197,7 @@ XICAttribute::setValuePreeditAttr(u_int16_t id, const QByteArray& data)
   
   case 16:
     Q_ASSERT(data.size() == sizeof(Cursor));
-    ds >> _cur_predt;
+    ds >> (uint&)_cur_predt;
     break;
   
   default:
@@ -209,21 +208,21 @@ XICAttribute::setValuePreeditAttr(u_int16_t id, const QByteArray& data)
 
 
 void
-XICAttribute::setValueStatusAttr(u_int16_t id, const QByteArray& data)
+XICAttribute::setValueStatusAttr(quint16 id, const QByteArray& data)
 {
-  QDataStream ds(data, IO_ReadOnly);
+  QDataStream ds(data);
   ds.setByteOrder(sysByteOrder());
   QByteArray fs;
-  u_int16_t len;
+  quint16 len;
 
   qDebug("%s id:%d data size:%d", __func__, id, data.size());
   switch (id) {
   case 6:
     ds >> len;
     fs.resize(len);
-    ds.readRawBytes(fs.data(), len);
+    ds.readRawData(fs.data(), len);
     _fontset_stat = QString(fs);
-    qDebug("Status Attributes FontSet:%d:%s", _fontset_stat.length(), _fontset_stat.data());
+    qDebug("Status Attributes FontSet:%d:%s", _fontset_stat.length(), qPrintable(_fontset_stat));
     break;
     
   case 7:
@@ -244,28 +243,28 @@ XICAttribute::setValueStatusAttr(u_int16_t id, const QByteArray& data)
     break;
     
   case 10:
-    Q_ASSERT(data.size() == sizeof(ulong));
+    Q_ASSERT(data.size() == sizeof(uint));
     ds >> _fg_stat;
     break;
     
   case 11:
-    Q_ASSERT(data.size() == sizeof(ulong));
+    Q_ASSERT(data.size() == sizeof(uint));
     ds >> _bg_stat;
     break;
     
   case 12:
     Q_ASSERT(data.size() == sizeof(Pixmap));
-    ds >> _bgpix_stat;
+    ds >> (uint&)_bgpix_stat;
     break;
     
   case 13:
     Q_ASSERT(data.size() == sizeof(Colormap));
-    ds >> _color_stat; 
+    ds >> (uint&)_color_stat; 
     break;
     
   case 14:
     Q_ASSERT(data.size() == sizeof(Atom));
-    ds >> _stdclr_stat;
+    ds >> (uint&)_stdclr_stat;
     break;
     
   case 15:
@@ -275,7 +274,7 @@ XICAttribute::setValueStatusAttr(u_int16_t id, const QByteArray& data)
     
   case 16:
     Q_ASSERT(data.size() == sizeof(Cursor));
-    ds >> _cur_stat;
+    ds >> (uint&)_cur_stat;
     break;
     
   default:
